@@ -49,6 +49,7 @@ try:
     from wwpdb.apps.ann_tasks_v2.related.UpdateRelated import UpdateRelated
     from wwpdb.apps.ann_tasks_v2.expIoUtils.PdbxExpUpdate import PdbxExpUpdate
     from wwpdb.utils.session.WebRequest import InputRequest
+    from wwpdb.io.locator.PathInfo import PathInfo
 except ImportError:
     pass
 
@@ -239,6 +240,39 @@ class AnnotationUtils(UtilsBase):
             traceback.print_exc(file=self._lfh)
             return False
 
+    def dictCheckFirstOp(self, **kwArgs):
+        """Performs PDBx dictionary check on the first block of a PDBx format input file
+        and returns a text check report.
+        """
+        try:
+            (inpObjD, outObjD, _uD, _pD) = self._getArgs(kwArgs)
+            pdbxPath = inpObjD["src"].getFilePathReference()
+
+            reportPath = outObjD["dst"].getFilePathReference()
+            dirPath = outObjD["dst"].getDirPathReference()
+            logPath = os.path.join(dirPath, "dict-check.log")
+            #
+            cI = ConfigInfo()
+            siteId = cI.get("SITE_PREFIX")
+            dp = RcsbDpUtility(tmpPath=dirPath, siteId=siteId, verbose=self._verbose, log=self._lfh)
+            dp.imp(pdbxPath)
+
+            dp.addInput("first_block")
+
+            #
+            dp.op("check-cif")
+            dp.expLog(logPath)
+            dp.exp(reportPath)
+            if self.__cleanUp:
+                dp.cleanup()
+            if self._verbose:
+                self._lfh.write("+AnnotationUtils.dictCheckOp() - PDBx input  file path:  %s\n" % pdbxPath)
+                self._lfh.write("+AnnotationUtils.dictCheckOp() - Report file path:       %s\n" % reportPath)
+            return True
+        except Exception as _e:  # noqa: F841
+            traceback.print_exc(file=self._lfh)
+            return False
+
     def dictR4CheckOp(self, **kwArgs):
         """Performs PDBx R4 dictionary check on PDBx format input file and returns a text check report."""
         try:
@@ -1234,18 +1268,38 @@ class AnnotationUtils(UtilsBase):
         :return bool: True if worked, False if failed
         """
         try:
-            (inpObjD, outObjD, _uD, _pD) = self._getArgs(kwArgs)
-            mapPath = inpObjD["src"].getFilePathReference()
+            (inpObjD, _outObjD, _uD, _pD) = self._getArgs(kwArgs)
+            modelPath = inpObjD["src"].getFilePathReference()
             # depDataSetId = inpObjD["src"].getDepositionDataSetId()
 
-            mapBcifPath = outObjD["dst"].getFilePathReference()
-            dirPath = outObjD["dst"].getDirPathReference()
-            if not os.path.exists(mapPath):
-                # no EM map
+            dirPath = inpObjD["src"].getDirPathReference()
+            if not os.path.exists(modelPath):
+                # no model
+                raise IOError("Missing model file")
+
+            ioObj = IoAdapterCore(verbose=self._verbose, log=self._lfh)
+            dIn = ioObj.readFile(inputFilePath=modelPath, selectList=["em_map"])
+            if not dIn or len(dIn) == 0:
                 return True
 
-            dw = DensityWrapper()
-            return dw.convert_em_volume(in_em_volume=mapPath, out_binary_volume=mapBcifPath, working_dir=dirPath)
+            cObj = dIn[0].getObj("em_map")
+            if not cObj:
+                # No em_map
+                return True
+
+            cI = ConfigInfo()
+            siteId = cI.get("SITE_PREFIX")
+            pi = PathInfo(siteId=siteId)
+
+            # loop through all the map file names in the mmcif file and convert to Bcif files
+            for mapNumber in range(0, len(cObj)):
+                mapName = cObj.getValue("file", mapNumber)
+                mapNameInfo = pi.parseFileName(mapName)
+                mapPath = pi.getFilePath(mapNameInfo[0], contentType=mapNameInfo[1], formatType=mapNameInfo[2], partNumber=mapNameInfo[3])
+                mapBcifPath = pi.getFilePath(mapNameInfo[0], contentType=mapNameInfo[1], formatType="bcif", partNumber=mapNameInfo[3])
+                dw = DensityWrapper()
+                dw.convert_em_volume(in_em_volume=mapPath, out_binary_volume=mapBcifPath, working_dir=dirPath)
+            return True
         except Exception as _e:  # noqa: F841
             traceback.print_exc(file=self._lfh)
             return False
